# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['craterpy', 'craterpy.tests']

package_data = \
{'': ['*'], 'craterpy': ['data/*', 'data/_images/*']}

install_requires = \
['matplotlib>=3.4.2,<4.0.0',
 'numpy>=1.20.2,<2.0.0',
 'pandas>=1.2.4,<2.0.0',
 'rasterio>=1.2.3,<2.0.0']

setup_kwargs = {
    'name': 'craterpy',
    'version': '0.4.1',
    'description': 'A package for impact crater data science.',
    'long_description': 'craterpy |RtdBadge|_ |PyPiBadge|_ |CodecovBadge|_ |ZenodoBadge|_\n================================================================================================\n.. |ZenodoBadge| image:: https://zenodo.org/badge/88457986.svg\n.. _ZenodoBadge: https://zenodo.org/badge/latestdoi/88457986\n\n.. |RtdBadge| image:: http://readthedocs.org/projects/craterpy/badge/?version=latest\n.. _RtdBadge: http://craterpy.readthedocs.io/en/latest/?badge=latest\n\n.. |PyPiBadge| image:: https://badge.fury.io/py/craterpy.svg\n.. _PyPiBadge: https://badge.fury.io/py/craterpy\n\n.. |CodecovBadge| image:: https://codecov.io/gh/cjtu/craterpy/branch/trunk/graph/badge.svg?token=9K567x0YUJ\n.. _CodecovBadge: https://codecov.io/gh/cjtu/craterpy\n\nOverview\n--------\nWelcome to craterpy (formerly *ACERIM*), your one-stop shop to crater data science in Python!\n\nThis package is in the alpha stage of development. You can direct any questions to Christian at cj.taiudovicic@gmail.com. Bug reports and feature requests can be opened as issues at the `issues`_ board on GitHub.\n\nYou can use craterpy to:\n\n  - work with tables of crater data in Python (using pandas)\n  - load and manipulate image data in Python (using rasterio)\n  - extract, mask, filter, and compute stats on craters located in your images\n  - plot crater data in python!\n\nCraterpy currently only supports simple cylindrical images and requires you to provide a table of crater locations and sizes (e.g. it isn\'t a crater detection program). See the example below!\n\nExample\n-------\nCraterpy in action::\n\n    import pandas as pd\n    from craterpy import dataset, stats\n    df = pd.DataFrame({\'Name\': ["Orientale", "Langrenus", "Compton"],\n                       \'Lat\': [-19.9, -8.86, 55.9],\n                       \'Lon\': [-94.7, 61.0, 104.0],\n                       \'Rad\': [147.0, 66.0, 82.3]})\n    moon = dataset.CraterpyDataset("moon.tif")\n    stat_df = cs.ejecta_stats(df, moon, 4, [\'mean\', \'median\', \'std\'], plot=True)\n\n\n.. image:: https://raw.githubusercontent.com/cjtu/craterpy/trunk/craterpy/data/_images/readme_crater_ejecta.png\n\n::\n\n  stats_df.head()\n\n.. image:: https://raw.githubusercontent.com/cjtu/craterpy/trunk/craterpy/data/_images/readme_stat_df.png\n\n\nNew users should start with the IPython notebook `tutorial`_ for typical usage with examples.\n\n**Note**: This package currently **only accepts image data in simple-cylindrical (Plate Caree) projection**. If your data is in another projection, please reproject it to simple-cylindrical before importing it with craterpy. If you would like add reprojection functionality to craterpy, consider `Contributing`_.\n\n.. _`tutorial`: https://gist.github.com/cjtu/560f121049b342aa0b2bf70e038358b7\n\n\nRequires\n--------\nCraterpy requires python >3.7 and is tested on Ubuntu and OS X. If you would like to use craterpy on Windows, we recommend getting the Windows Subsystem for Linux (`WSL`_) and installing it from the bash shell.\n\n.. _`WSL`: https://docs.microsoft.com/en-us/windows/wsl/install-win10\n\nIt\'s core dependencies are:\n\n- rasterio\n- pandas\n- numpy\n- matplotlib\n\nInstallation\n------------\n\nThe most reliable way to get craterpy is by installing `git <https://git-scm.com>`_ and `poetry <https://python-poetry.org/docs/>`_ to clone and install the package.\n\nYou can clone and install craterpy with the following steps::\n\n    # Clone this repository\n    $ cd ~\n    $ git clone https://github.com/cjtu/craterpy.git\n\n    # Enter the repository\n    $ cd craterpy\n\n    # Configure poetry\n    poetry config virtualenvs.create true --local\n    poetry config virtualenvs.in-project true --local\n\n    # Install craterpy with poetry\n    $ poetry install\n\n    # Check installation\n    poetry version\n\n    # Either open a Jupyter server\n    $ poetry run jupyter notebook\n\n    # Or activate the venv from your Python editor of choice\n    # The venv is path is ~/craterpy/.venv/bin/python\n\nInstalling from pip\n-------------------\n\nCraterpy is also listed on `PYPI <https://pypi.org/project/craterpy/>`_ and can be installed with `pip <https://packaging.python.org/tutorials/installing-packages/>`_::\n\n    pip install craterpy\n    python -c "import craterpy; print(craterpy.__version__)"\n\nInstalling into a conda environment\n-----------------------------------\n\nYou can similarly install craterpy into a `conda environment`_ using pip::\n\n    # Create conda environment\n    conda create -n craterpy python=3.7\n\n    # Activate the environment\n    conda activate craterpy\n\n    # Install dependencies (optional, but may fix dependency issues on some platforms)\n    conda install -c conda-forge rasterio pandas, numpy, matplotlib\n\n    # Install craterpy\n    pip install craterpy\n\n    # Test installation\n    python -c "import craterpy; print(craterpy.__version__)"\n\nTrouble installing craterpy? Let us know on the `issues`_ board.\n\nNow that you have craterpy installed, head over to the `tutorial`_ to get started!\n\n.. _`conda environment`: https://conda.io/docs/using/envs\n\nInstalling from a fork\n^^^^^^^^^^^^^^^^^^^^^^\n\n1. Fork this project from `craterpy on GitHub`_.\n2. Clone your fork locally\n3. Navigate to the craterpy root directory and install with::\n\n    python setup.py install\n\n**Warning**: This installs the newest craterpy updates which may not be production stable. Installing from pip automatically pulls the previous stable release.\n\n.. _`craterpy on GitHub`: https://github.com/cjtu/craterpy\n\nDocumentation\n-------------\n\nAPI documentation is available at `readthedocs <https://readthedocs.org/projects/craterpy/>`_.\n\n\nContributing\n------------\nThere are two major ways you can help improve craterpy:\n\nBug Reporting and Feature Requests\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\nYou can report bugs or request new features on the `issues`_ board. If you are reporting a bug, please give a detailed description about how it came up and what your build environment is (e.g. with ``conda list``).\n\n.. _`issues`: https://github.com/cjtu/craterpy/issues\n\nBecoming a contributor\n^^^^^^^^^^^^^^^^^^^^^^\ncraterpy is seeking new contributors! If you are interested in open source and want to join a supportive learning environment - or if you want to extend craterpy to suit your own crater analysis - consider contributing to the project! See `CONTRIBUTING.rst`_ for details on how to get started.\n\n.. _`CONTRIBUTING.rst`: https://github.com/cjtu/craterpy/blob/master/CONTRIBUTING.rst\n\nDevelopment Environment\n"""""""""""""""""""""""\nThe development environment is specified in `.environment.yml`. It can be built automatically in a new conda environment in a few simple steps:\n\n1. Fork `craterpy on GitHub`_.\n\n2. Clone your fork, then cd into your local craterpy repository.\n\n3. Install the dependencies using poetry (steps above).\n\n4. Run a jupyter notebook with::\n\n    poetry run jupyter notebook\n\n5. Test your changes::\n\n    poetry run pytest craterpy\n\n6. Apply code formatting with black::\n\n    poetry run black craterpy\n\n7. Run pylint to check your code style::\n\n    poetry run pylint craterpy\n\n8. Hack away!\n\nRead more about testing, contributing and style in `CONTRIBUTING.rst`_.\n\n\nCiting craterpy\n---------------\n\nFor convenience, this project uses the `MIT Licence <https://github.com/cjtu/craterpy/blob/master/LICENSE.txt>`_ for warranty-free ease of use and distribution. The author simply asks that you cite the project when using it in published research. The `citable DOI <https://zenodo.org/badge/latestdoi/88457986>`_ can be found at Zenodo by clicking the badge below.\n\n.. image:: https://zenodo.org/badge/88457986.svg\n    :target: https://zenodo.org/badge/latestdoi/88457986\n\nTo read more about citable code, check out `Zenodo <http://help.zenodo.org/features>`_.\n\n\nContact\n-------\nIf you have comments/question/concerns or just want to get in touch, you can email Christian at cj.taiudovicic@gmail.com or follow `@TaiUdovicic <https://twitter.com/TaiUdovicic>`_ on Twitter.\n\n\nLicense\n-------\n\nCopyright (c) 2021- Christian Tai Udovicic. Released under the MIT license. This software comes with no warranties. See `LICENSE <https://github.com/cjtu/craterpy/blob/master/LICENSE.txt>`_ for details.\n\n\nContributors\n------------\nCraterpy was developed with the aid of `these wonderful people <https://github.com/cjtu/craterpy/graphs/contributors>`_!\n',
    'author': 'Christian J. Tai Udovicic',
    'author_email': 'cj.taiudovicic@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/cjtu/craterpy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.7,<4.0.0',
}


setup(**setup_kwargs)
